# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2/proto/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from dialogflow_v2.proto import (
    validation_result_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_validation__result__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2/proto/agent.proto",
    package="google.cloud.dialogflow.v2",
    syntax="proto3",
    serialized_options=b"\n\036com.google.cloud.dialogflow.v2B\nAgentProtoP\001ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\370\001\001\242\002\002DF\252\002\032Google.Cloud.Dialogflow.V2",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n,google/cloud/dialogflow_v2/proto/agent.proto\x12\x1agoogle.cloud.dialogflow.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x38google/cloud/dialogflow_v2/proto/validation_result.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xf0\x06\n\x05\x41gent\x12\x43\n\x06parent\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12"\n\x15\x64\x65\x66\x61ult_language_code\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12%\n\x18supported_language_codes\x18\x04 \x03(\tB\x03\xe0\x41\x01\x12\x16\n\ttime_zone\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x17\n\navatar_uri\x18\x07 \x01(\tB\x03\xe0\x41\x01\x12\x1b\n\x0e\x65nable_logging\x18\x08 \x01(\x08\x42\x03\xe0\x41\x01\x12\x44\n\nmatch_mode\x18\t \x01(\x0e\x32+.google.cloud.dialogflow.v2.Agent.MatchModeB\x03\xe0\x41\x01\x12%\n\x18\x63lassification_threshold\x18\n \x01(\x02\x42\x03\xe0\x41\x01\x12\x46\n\x0b\x61pi_version\x18\x0e \x01(\x0e\x32,.google.cloud.dialogflow.v2.Agent.ApiVersionB\x03\xe0\x41\x01\x12\x39\n\x04tier\x18\x0f \x01(\x0e\x32&.google.cloud.dialogflow.v2.Agent.TierB\x03\xe0\x41\x01"V\n\tMatchMode\x12\x1a\n\x16MATCH_MODE_UNSPECIFIED\x10\x00\x12\x15\n\x11MATCH_MODE_HYBRID\x10\x01\x12\x16\n\x12MATCH_MODE_ML_ONLY\x10\x02"l\n\nApiVersion\x12\x1b\n\x17\x41PI_VERSION_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41PI_VERSION_V1\x10\x01\x12\x12\n\x0e\x41PI_VERSION_V2\x10\x02\x12\x19\n\x15\x41PI_VERSION_V2_BETA_1\x10\x03"^\n\x04Tier\x12\x14\n\x10TIER_UNSPECIFIED\x10\x00\x12\x11\n\rTIER_STANDARD\x10\x01\x12\x13\n\x0fTIER_ENTERPRISE\x10\x02\x12\x18\n\x14TIER_ENTERPRISE_PLUS\x10\x03:>\xea\x41;\n\x1f\x64ialogflow.googleapis.com/Agent\x12\x18projects/{project}/agent"J\n\x0fGetAgentRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent"~\n\x0fSetAgentRequest\x12\x35\n\x05\x61gent\x18\x01 \x01(\x0b\x32!.google.cloud.dialogflow.v2.AgentB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01"M\n\x12\x44\x65leteAgentRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent"z\n\x13SearchAgentsRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x12\n\npage_token\x18\x03 \x01(\t"b\n\x14SearchAgentsResponse\x12\x31\n\x06\x61gents\x18\x01 \x03(\x0b\x32!.google.cloud.dialogflow.v2.Agent\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"L\n\x11TrainAgentRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent"e\n\x12\x45xportAgentRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent\x12\x16\n\tagent_uri\x18\x02 \x01(\tB\x03\xe0\x41\x02"L\n\x13\x45xportAgentResponse\x12\x13\n\tagent_uri\x18\x01 \x01(\tH\x00\x12\x17\n\ragent_content\x18\x02 \x01(\x0cH\x00\x42\x07\n\x05\x61gent"\x84\x01\n\x12ImportAgentRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent\x12\x13\n\tagent_uri\x18\x02 \x01(\tH\x00\x12\x17\n\ragent_content\x18\x03 \x01(\x0cH\x00\x42\x07\n\x05\x61gent"\x85\x01\n\x13RestoreAgentRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent\x12\x13\n\tagent_uri\x18\x02 \x01(\tH\x00\x12\x17\n\ragent_content\x18\x03 \x01(\x0cH\x00\x42\x07\n\x05\x61gent"q\n\x1aGetValidationResultRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x64ialogflow.googleapis.com/Agent\x12\x1a\n\rlanguage_code\x18\x03 \x01(\tB\x03\xe0\x41\x01\x32\xc5\r\n\x06\x41gents\x12\x8a\x01\n\x08GetAgent\x12+.google.cloud.dialogflow.v2.GetAgentRequest\x1a!.google.cloud.dialogflow.v2.Agent".\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v2/{parent=projects/*}/agent\xda\x41\x06parent\x12\x96\x01\n\x08SetAgent\x12+.google.cloud.dialogflow.v2.SetAgentRequest\x1a!.google.cloud.dialogflow.v2.Agent":\x82\xd3\xe4\x93\x02,"#/v2/{agent.parent=projects/*}/agent:\x05\x61gent\xda\x41\x05\x61gent\x12\x85\x01\n\x0b\x44\x65leteAgent\x12..google.cloud.dialogflow.v2.DeleteAgentRequest\x1a\x16.google.protobuf.Empty".\x82\xd3\xe4\x93\x02\x1f*\x1d/v2/{parent=projects/*}/agent\xda\x41\x06parent\x12\xa8\x01\n\x0cSearchAgents\x12/.google.cloud.dialogflow.v2.SearchAgentsRequest\x1a\x30.google.cloud.dialogflow.v2.SearchAgentsResponse"5\x82\xd3\xe4\x93\x02&\x12$/v2/{parent=projects/*}/agent:search\xda\x41\x06parent\x12\xc5\x01\n\nTrainAgent\x12-.google.cloud.dialogflow.v2.TrainAgentRequest\x1a\x1d.google.longrunning.Operation"i\x82\xd3\xe4\x93\x02("#/v2/{parent=projects/*}/agent:train:\x01*\xda\x41\x06parent\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x12\xe2\x01\n\x0b\x45xportAgent\x12..google.cloud.dialogflow.v2.ExportAgentRequest\x1a\x1d.google.longrunning.Operation"\x83\x01\x82\xd3\xe4\x93\x02)"$/v2/{parent=projects/*}/agent:export:\x01*\xda\x41\x06parent\xca\x41H\n.google.cloud.dialogflow.v2.ExportAgentResponse\x12\x16google.protobuf.Struct\x12\xbf\x01\n\x0bImportAgent\x12..google.cloud.dialogflow.v2.ImportAgentRequest\x1a\x1d.google.longrunning.Operation"a\x82\xd3\xe4\x93\x02)"$/v2/{parent=projects/*}/agent:import:\x01*\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x12\xc2\x01\n\x0cRestoreAgent\x12/.google.cloud.dialogflow.v2.RestoreAgentRequest\x1a\x1d.google.longrunning.Operation"b\x82\xd3\xe4\x93\x02*"%/v2/{parent=projects/*}/agent:restore:\x01*\xca\x41/\n\x15google.protobuf.Empty\x12\x16google.protobuf.Struct\x12\xb3\x01\n\x13GetValidationResult\x12\x36.google.cloud.dialogflow.v2.GetValidationResultRequest\x1a,.google.cloud.dialogflow.v2.ValidationResult"6\x82\xd3\xe4\x93\x02\x30\x12./v2/{parent=projects/*}/agent/validationResult\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\x99\x01\n\x1e\x63om.google.cloud.dialogflow.v2B\nAgentProtoP\x01ZDgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1aGoogle.Cloud.Dialogflow.V2b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_validation__result__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_AGENT_MATCHMODE = _descriptor.EnumDescriptor(
    name="MatchMode",
    full_name="google.cloud.dialogflow.v2.Agent.MatchMode",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="MATCH_MODE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MATCH_MODE_HYBRID",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MATCH_MODE_ML_ONLY",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=874,
    serialized_end=960,
)
_sym_db.RegisterEnumDescriptor(_AGENT_MATCHMODE)

_AGENT_APIVERSION = _descriptor.EnumDescriptor(
    name="ApiVersion",
    full_name="google.cloud.dialogflow.v2.Agent.ApiVersion",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="API_VERSION_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="API_VERSION_V1",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="API_VERSION_V2",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="API_VERSION_V2_BETA_1",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=962,
    serialized_end=1070,
)
_sym_db.RegisterEnumDescriptor(_AGENT_APIVERSION)

_AGENT_TIER = _descriptor.EnumDescriptor(
    name="Tier",
    full_name="google.cloud.dialogflow.v2.Agent.Tier",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TIER_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TIER_STANDARD",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TIER_ENTERPRISE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="TIER_ENTERPRISE_PLUS",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1072,
    serialized_end=1166,
)
_sym_db.RegisterEnumDescriptor(_AGENT_TIER)


_AGENT = _descriptor.Descriptor(
    name="Agent",
    full_name="google.cloud.dialogflow.v2.Agent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.Agent.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+cloudresourcemanager.googleapis.com/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2.Agent.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_language_code",
            full_name="google.cloud.dialogflow.v2.Agent.default_language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="supported_language_codes",
            full_name="google.cloud.dialogflow.v2.Agent.supported_language_codes",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="time_zone",
            full_name="google.cloud.dialogflow.v2.Agent.time_zone",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2.Agent.description",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="avatar_uri",
            full_name="google.cloud.dialogflow.v2.Agent.avatar_uri",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enable_logging",
            full_name="google.cloud.dialogflow.v2.Agent.enable_logging",
            index=7,
            number=8,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="match_mode",
            full_name="google.cloud.dialogflow.v2.Agent.match_mode",
            index=8,
            number=9,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="classification_threshold",
            full_name="google.cloud.dialogflow.v2.Agent.classification_threshold",
            index=9,
            number=10,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="api_version",
            full_name="google.cloud.dialogflow.v2.Agent.api_version",
            index=10,
            number=14,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tier",
            full_name="google.cloud.dialogflow.v2.Agent.tier",
            index=11,
            number=15,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_AGENT_MATCHMODE, _AGENT_APIVERSION, _AGENT_TIER],
    serialized_options=b"\352A;\n\037dialogflow.googleapis.com/Agent\022\030projects/{project}/agent",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=350,
    serialized_end=1230,
)


_GETAGENTREQUEST = _descriptor.Descriptor(
    name="GetAgentRequest",
    full_name="google.cloud.dialogflow.v2.GetAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.GetAgentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1232,
    serialized_end=1306,
)


_SETAGENTREQUEST = _descriptor.Descriptor(
    name="SetAgentRequest",
    full_name="google.cloud.dialogflow.v2.SetAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="agent",
            full_name="google.cloud.dialogflow.v2.SetAgentRequest.agent",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2.SetAgentRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1308,
    serialized_end=1434,
)


_DELETEAGENTREQUEST = _descriptor.Descriptor(
    name="DeleteAgentRequest",
    full_name="google.cloud.dialogflow.v2.DeleteAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.DeleteAgentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1436,
    serialized_end=1513,
)


_SEARCHAGENTSREQUEST = _descriptor.Descriptor(
    name="SearchAgentsRequest",
    full_name="google.cloud.dialogflow.v2.SearchAgentsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.SearchAgentsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2.SearchAgentsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2.SearchAgentsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1515,
    serialized_end=1637,
)


_SEARCHAGENTSRESPONSE = _descriptor.Descriptor(
    name="SearchAgentsResponse",
    full_name="google.cloud.dialogflow.v2.SearchAgentsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="agents",
            full_name="google.cloud.dialogflow.v2.SearchAgentsResponse.agents",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2.SearchAgentsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1639,
    serialized_end=1737,
)


_TRAINAGENTREQUEST = _descriptor.Descriptor(
    name="TrainAgentRequest",
    full_name="google.cloud.dialogflow.v2.TrainAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.TrainAgentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1739,
    serialized_end=1815,
)


_EXPORTAGENTREQUEST = _descriptor.Descriptor(
    name="ExportAgentRequest",
    full_name="google.cloud.dialogflow.v2.ExportAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.ExportAgentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_uri",
            full_name="google.cloud.dialogflow.v2.ExportAgentRequest.agent_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1817,
    serialized_end=1918,
)


_EXPORTAGENTRESPONSE = _descriptor.Descriptor(
    name="ExportAgentResponse",
    full_name="google.cloud.dialogflow.v2.ExportAgentResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="agent_uri",
            full_name="google.cloud.dialogflow.v2.ExportAgentResponse.agent_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_content",
            full_name="google.cloud.dialogflow.v2.ExportAgentResponse.agent_content",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="agent",
            full_name="google.cloud.dialogflow.v2.ExportAgentResponse.agent",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=1920,
    serialized_end=1996,
)


_IMPORTAGENTREQUEST = _descriptor.Descriptor(
    name="ImportAgentRequest",
    full_name="google.cloud.dialogflow.v2.ImportAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.ImportAgentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_uri",
            full_name="google.cloud.dialogflow.v2.ImportAgentRequest.agent_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_content",
            full_name="google.cloud.dialogflow.v2.ImportAgentRequest.agent_content",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="agent",
            full_name="google.cloud.dialogflow.v2.ImportAgentRequest.agent",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=1999,
    serialized_end=2131,
)


_RESTOREAGENTREQUEST = _descriptor.Descriptor(
    name="RestoreAgentRequest",
    full_name="google.cloud.dialogflow.v2.RestoreAgentRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.RestoreAgentRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_uri",
            full_name="google.cloud.dialogflow.v2.RestoreAgentRequest.agent_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_content",
            full_name="google.cloud.dialogflow.v2.RestoreAgentRequest.agent_content",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="agent",
            full_name="google.cloud.dialogflow.v2.RestoreAgentRequest.agent",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        )
    ],
    serialized_start=2134,
    serialized_end=2267,
)


_GETVALIDATIONRESULTREQUEST = _descriptor.Descriptor(
    name="GetValidationResultRequest",
    full_name="google.cloud.dialogflow.v2.GetValidationResultRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2.GetValidationResultRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037dialogflow.googleapis.com/Agent",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2.GetValidationResultRequest.language_code",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2269,
    serialized_end=2382,
)

_AGENT.fields_by_name["match_mode"].enum_type = _AGENT_MATCHMODE
_AGENT.fields_by_name["api_version"].enum_type = _AGENT_APIVERSION
_AGENT.fields_by_name["tier"].enum_type = _AGENT_TIER
_AGENT_MATCHMODE.containing_type = _AGENT
_AGENT_APIVERSION.containing_type = _AGENT
_AGENT_TIER.containing_type = _AGENT
_SETAGENTREQUEST.fields_by_name["agent"].message_type = _AGENT
_SETAGENTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_SEARCHAGENTSRESPONSE.fields_by_name["agents"].message_type = _AGENT
_EXPORTAGENTRESPONSE.oneofs_by_name["agent"].fields.append(
    _EXPORTAGENTRESPONSE.fields_by_name["agent_uri"]
)
_EXPORTAGENTRESPONSE.fields_by_name[
    "agent_uri"
].containing_oneof = _EXPORTAGENTRESPONSE.oneofs_by_name["agent"]
_EXPORTAGENTRESPONSE.oneofs_by_name["agent"].fields.append(
    _EXPORTAGENTRESPONSE.fields_by_name["agent_content"]
)
_EXPORTAGENTRESPONSE.fields_by_name[
    "agent_content"
].containing_oneof = _EXPORTAGENTRESPONSE.oneofs_by_name["agent"]
_IMPORTAGENTREQUEST.oneofs_by_name["agent"].fields.append(
    _IMPORTAGENTREQUEST.fields_by_name["agent_uri"]
)
_IMPORTAGENTREQUEST.fields_by_name[
    "agent_uri"
].containing_oneof = _IMPORTAGENTREQUEST.oneofs_by_name["agent"]
_IMPORTAGENTREQUEST.oneofs_by_name["agent"].fields.append(
    _IMPORTAGENTREQUEST.fields_by_name["agent_content"]
)
_IMPORTAGENTREQUEST.fields_by_name[
    "agent_content"
].containing_oneof = _IMPORTAGENTREQUEST.oneofs_by_name["agent"]
_RESTOREAGENTREQUEST.oneofs_by_name["agent"].fields.append(
    _RESTOREAGENTREQUEST.fields_by_name["agent_uri"]
)
_RESTOREAGENTREQUEST.fields_by_name[
    "agent_uri"
].containing_oneof = _RESTOREAGENTREQUEST.oneofs_by_name["agent"]
_RESTOREAGENTREQUEST.oneofs_by_name["agent"].fields.append(
    _RESTOREAGENTREQUEST.fields_by_name["agent_content"]
)
_RESTOREAGENTREQUEST.fields_by_name[
    "agent_content"
].containing_oneof = _RESTOREAGENTREQUEST.oneofs_by_name["agent"]
DESCRIPTOR.message_types_by_name["Agent"] = _AGENT
DESCRIPTOR.message_types_by_name["GetAgentRequest"] = _GETAGENTREQUEST
DESCRIPTOR.message_types_by_name["SetAgentRequest"] = _SETAGENTREQUEST
DESCRIPTOR.message_types_by_name["DeleteAgentRequest"] = _DELETEAGENTREQUEST
DESCRIPTOR.message_types_by_name["SearchAgentsRequest"] = _SEARCHAGENTSREQUEST
DESCRIPTOR.message_types_by_name["SearchAgentsResponse"] = _SEARCHAGENTSRESPONSE
DESCRIPTOR.message_types_by_name["TrainAgentRequest"] = _TRAINAGENTREQUEST
DESCRIPTOR.message_types_by_name["ExportAgentRequest"] = _EXPORTAGENTREQUEST
DESCRIPTOR.message_types_by_name["ExportAgentResponse"] = _EXPORTAGENTRESPONSE
DESCRIPTOR.message_types_by_name["ImportAgentRequest"] = _IMPORTAGENTREQUEST
DESCRIPTOR.message_types_by_name["RestoreAgentRequest"] = _RESTOREAGENTREQUEST
DESCRIPTOR.message_types_by_name[
    "GetValidationResultRequest"
] = _GETVALIDATIONRESULTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Agent = _reflection.GeneratedProtocolMessageType(
    "Agent",
    (_message.Message,),
    {
        "DESCRIPTOR": _AGENT,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """A Dialogflow agent is a virtual agent that handles conversations with
  your end-users. It is a natural language understanding module that
  understands the nuances of human language. Dialogflow translates end-
  user text or audio during a conversation to structured data that your
  apps and services can understand. You design and build a Dialogflow
  agent to handle the types of conversations required for your system.
  For more information about agents, see the `Agent guide
  <https://cloud.google.com/dialogflow/docs/agents-overview>`__.
  
  Attributes:
      parent:
          Required. The project of this agent. Format:
          ``projects/<Project ID>``.
      display_name:
          Required. The name of this agent.
      default_language_code:
          Required. The default language of the agent as a language tag.
          See `Language Support <https://cloud.google.com/dialogflow/doc
          s/reference/language>`__ for a list of the currently supported
          language codes. This field cannot be set by the ``Update``
          method.
      supported_language_codes:
          Optional. The list of all languages supported by this agent
          (except for the ``default_language_code``).
      time_zone:
          Required. The time zone of this agent from the `time zone
          database <https://www.iana.org/time-zones>`__, e.g.,
          America/New_York, Europe/Paris.
      description:
          Optional. The description of this agent. The maximum length is
          500 characters. If exceeded, the request is rejected.
      avatar_uri:
          Optional. The URI of the agent’s avatar. Avatars are used
          throughout the Dialogflow console and in the self-hosted `Web
          Demo
          <https://cloud.google.com/dialogflow/docs/integrations/web-
          demo>`__ integration.
      enable_logging:
          Optional. Determines whether this agent should log
          conversation queries.
      match_mode:
          Optional. Determines how intents are detected from user
          queries.
      classification_threshold:
          Optional. To filter out false positive results and still get
          variety in matched natural language inputs for your agent, you
          can tune the machine learning classification threshold. If the
          returned score value is less than the threshold value, then a
          fallback intent will be triggered or, if there are no fallback
          intents defined, no intent will be triggered. The score values
          range from 0.0 (completely uncertain) to 1.0 (completely
          certain). If set to 0.0, the default of 0.3 is used.
      api_version:
          Optional. API version displayed in Dialogflow console. If not
          specified, V2 API is assumed. Clients are free to query
          different service endpoints for different API versions.
          However, bots connectors and webhook calls will follow the
          specified API version.
      tier:
          Optional. The agent tier. If not specified, TIER_STANDARD is
          assumed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.Agent)
    },
)
_sym_db.RegisterMessage(Agent)

GetAgentRequest = _reflection.GeneratedProtocolMessageType(
    "GetAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.GetAgent][google.cloud.dialogflow.v2.Agents.GetAgent].
  
  Attributes:
      parent:
          Required. The project that the agent to fetch is associated
          with. Format: ``projects/<Project ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.GetAgentRequest)
    },
)
_sym_db.RegisterMessage(GetAgentRequest)

SetAgentRequest = _reflection.GeneratedProtocolMessageType(
    "SetAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SETAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.SetAgent][google.cloud.dialogflow.v2.Agents.SetAgent].
  
  Attributes:
      agent:
          Required. The agent to update.
      update_mask:
          Optional. The mask to control which fields get updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.SetAgentRequest)
    },
)
_sym_db.RegisterMessage(SetAgentRequest)

DeleteAgentRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.DeleteAgent][google.cloud.dialogflow.v2.Agents.DeleteAgent].
  
  Attributes:
      parent:
          Required. The project that the agent to delete is associated
          with. Format: ``projects/<Project ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.DeleteAgentRequest)
    },
)
_sym_db.RegisterMessage(DeleteAgentRequest)

SearchAgentsRequest = _reflection.GeneratedProtocolMessageType(
    "SearchAgentsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHAGENTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.SearchAgents][google.cloud.dialogflow.v2.Agents.SearchAgents].
  
  Attributes:
      parent:
          Required. The project to list agents from. Format:
          ``projects/<Project ID or '-'>``.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 100 and at most 1000.
      page_token:
          The next_page_token value returned from a previous list
          request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.SearchAgentsRequest)
    },
)
_sym_db.RegisterMessage(SearchAgentsRequest)

SearchAgentsResponse = _reflection.GeneratedProtocolMessageType(
    "SearchAgentsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHAGENTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The response message for
  [Agents.SearchAgents][google.cloud.dialogflow.v2.Agents.SearchAgents].
  
  Attributes:
      agents:
          The list of agents. There will be a maximum number of items
          returned based on the page_size field in the request.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.SearchAgentsResponse)
    },
)
_sym_db.RegisterMessage(SearchAgentsResponse)

TrainAgentRequest = _reflection.GeneratedProtocolMessageType(
    "TrainAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _TRAINAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.TrainAgent][google.cloud.dialogflow.v2.Agents.TrainAgent].
  
  Attributes:
      parent:
          Required. The project that the agent to train is associated
          with. Format: ``projects/<Project ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.TrainAgentRequest)
    },
)
_sym_db.RegisterMessage(TrainAgentRequest)

ExportAgentRequest = _reflection.GeneratedProtocolMessageType(
    "ExportAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.ExportAgent][google.cloud.dialogflow.v2.Agents.ExportAgent].
  
  Attributes:
      parent:
          Required. The project that the agent to export is associated
          with. Format: ``projects/<Project ID>``.
      agent_uri:
          Required. The `Google Cloud Storage
          <https://cloud.google.com/storage/docs/>`__ URI to export the
          agent to. The format of this URI must be ``gs://<bucket-
          name>/<object-name>``. If left unspecified, the serialized
          agent is returned inline.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.ExportAgentRequest)
    },
)
_sym_db.RegisterMessage(ExportAgentRequest)

ExportAgentResponse = _reflection.GeneratedProtocolMessageType(
    "ExportAgentResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTAGENTRESPONSE,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The response message for
  [Agents.ExportAgent][google.cloud.dialogflow.v2.Agents.ExportAgent].
  
  Attributes:
      agent:
          The exported agent.
      agent_uri:
          The URI to a file containing the exported agent. This field is
          populated only if ``agent_uri`` is specified in
          ``ExportAgentRequest``.
      agent_content:
          Zip compressed raw byte content for agent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.ExportAgentResponse)
    },
)
_sym_db.RegisterMessage(ExportAgentResponse)

ImportAgentRequest = _reflection.GeneratedProtocolMessageType(
    "ImportAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMPORTAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.ImportAgent][google.cloud.dialogflow.v2.Agents.ImportAgent].
  
  Attributes:
      parent:
          Required. The project that the agent to import is associated
          with. Format: ``projects/<Project ID>``.
      agent:
          Required. The agent to import.
      agent_uri:
          The URI to a Google Cloud Storage file containing the agent to
          import. Note: The URI must start with “gs://”.
      agent_content:
          Zip compressed raw byte content for agent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.ImportAgentRequest)
    },
)
_sym_db.RegisterMessage(ImportAgentRequest)

RestoreAgentRequest = _reflection.GeneratedProtocolMessageType(
    "RestoreAgentRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESTOREAGENTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for
  [Agents.RestoreAgent][google.cloud.dialogflow.v2.Agents.RestoreAgent].
  
  Attributes:
      parent:
          Required. The project that the agent to restore is associated
          with. Format: ``projects/<Project ID>``.
      agent:
          Required. The agent to restore.
      agent_uri:
          The URI to a Google Cloud Storage file containing the agent to
          restore. Note: The URI must start with “gs://”.
      agent_content:
          Zip compressed raw byte content for agent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.RestoreAgentRequest)
    },
)
_sym_db.RegisterMessage(RestoreAgentRequest)

GetValidationResultRequest = _reflection.GeneratedProtocolMessageType(
    "GetValidationResultRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETVALIDATIONRESULTREQUEST,
        "__module__": "google.cloud.dialogflow_v2.proto.agent_pb2",
        "__doc__": """The request message for [Agents.GetValidationResult][google.cloud.dial
  ogflow.v2.Agents.GetValidationResult].
  
  Attributes:
      parent:
          Required. The project that the agent is associated with.
          Format: ``projects/<Project ID>``.
      language_code:
          Optional. The language for which you want a validation result.
          If not specified, the agent’s default language is used. `Many
          languages <https://cloud.google.com/dialogflow/docs/reference/
          language>`__ are supported. Note: languages must be enabled in
          the agent before they can be used.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2.GetValidationResultRequest)
    },
)
_sym_db.RegisterMessage(GetValidationResultRequest)


DESCRIPTOR._options = None
_AGENT.fields_by_name["parent"]._options = None
_AGENT.fields_by_name["display_name"]._options = None
_AGENT.fields_by_name["default_language_code"]._options = None
_AGENT.fields_by_name["supported_language_codes"]._options = None
_AGENT.fields_by_name["time_zone"]._options = None
_AGENT.fields_by_name["description"]._options = None
_AGENT.fields_by_name["avatar_uri"]._options = None
_AGENT.fields_by_name["enable_logging"]._options = None
_AGENT.fields_by_name["match_mode"]._options = None
_AGENT.fields_by_name["classification_threshold"]._options = None
_AGENT.fields_by_name["api_version"]._options = None
_AGENT.fields_by_name["tier"]._options = None
_AGENT._options = None
_GETAGENTREQUEST.fields_by_name["parent"]._options = None
_SETAGENTREQUEST.fields_by_name["agent"]._options = None
_SETAGENTREQUEST.fields_by_name["update_mask"]._options = None
_DELETEAGENTREQUEST.fields_by_name["parent"]._options = None
_SEARCHAGENTSREQUEST.fields_by_name["parent"]._options = None
_SEARCHAGENTSREQUEST.fields_by_name["page_size"]._options = None
_TRAINAGENTREQUEST.fields_by_name["parent"]._options = None
_EXPORTAGENTREQUEST.fields_by_name["parent"]._options = None
_EXPORTAGENTREQUEST.fields_by_name["agent_uri"]._options = None
_IMPORTAGENTREQUEST.fields_by_name["parent"]._options = None
_RESTOREAGENTREQUEST.fields_by_name["parent"]._options = None
_GETVALIDATIONRESULTREQUEST.fields_by_name["parent"]._options = None
_GETVALIDATIONRESULTREQUEST.fields_by_name["language_code"]._options = None

_AGENTS = _descriptor.ServiceDescriptor(
    name="Agents",
    full_name="google.cloud.dialogflow.v2.Agents",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=2385,
    serialized_end=4118,
    methods=[
        _descriptor.MethodDescriptor(
            name="GetAgent",
            full_name="google.cloud.dialogflow.v2.Agents.GetAgent",
            index=0,
            containing_service=None,
            input_type=_GETAGENTREQUEST,
            output_type=_AGENT,
            serialized_options=b"\202\323\344\223\002\037\022\035/v2/{parent=projects/*}/agent\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SetAgent",
            full_name="google.cloud.dialogflow.v2.Agents.SetAgent",
            index=1,
            containing_service=None,
            input_type=_SETAGENTREQUEST,
            output_type=_AGENT,
            serialized_options=b'\202\323\344\223\002,"#/v2/{agent.parent=projects/*}/agent:\005agent\332A\005agent',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteAgent",
            full_name="google.cloud.dialogflow.v2.Agents.DeleteAgent",
            index=2,
            containing_service=None,
            input_type=_DELETEAGENTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\037*\035/v2/{parent=projects/*}/agent\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SearchAgents",
            full_name="google.cloud.dialogflow.v2.Agents.SearchAgents",
            index=3,
            containing_service=None,
            input_type=_SEARCHAGENTSREQUEST,
            output_type=_SEARCHAGENTSRESPONSE,
            serialized_options=b"\202\323\344\223\002&\022$/v2/{parent=projects/*}/agent:search\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="TrainAgent",
            full_name="google.cloud.dialogflow.v2.Agents.TrainAgent",
            index=4,
            containing_service=None,
            input_type=_TRAINAGENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002("#/v2/{parent=projects/*}/agent:train:\001*\332A\006parent\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExportAgent",
            full_name="google.cloud.dialogflow.v2.Agents.ExportAgent",
            index=5,
            containing_service=None,
            input_type=_EXPORTAGENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002)"$/v2/{parent=projects/*}/agent:export:\001*\332A\006parent\312AH\n.google.cloud.dialogflow.v2.ExportAgentResponse\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ImportAgent",
            full_name="google.cloud.dialogflow.v2.Agents.ImportAgent",
            index=6,
            containing_service=None,
            input_type=_IMPORTAGENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002)"$/v2/{parent=projects/*}/agent:import:\001*\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RestoreAgent",
            full_name="google.cloud.dialogflow.v2.Agents.RestoreAgent",
            index=7,
            containing_service=None,
            input_type=_RESTOREAGENTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002*"%/v2/{parent=projects/*}/agent:restore:\001*\312A/\n\025google.protobuf.Empty\022\026google.protobuf.Struct',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetValidationResult",
            full_name="google.cloud.dialogflow.v2.Agents.GetValidationResult",
            index=8,
            containing_service=None,
            input_type=_GETVALIDATIONRESULTREQUEST,
            output_type=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_validation__result__pb2._VALIDATIONRESULT,
            serialized_options=b"\202\323\344\223\0020\022./v2/{parent=projects/*}/agent/validationResult",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_AGENTS)

DESCRIPTOR.services_by_name["Agents"] = _AGENTS

# @@protoc_insertion_point(module_scope)
